@@ -9,7 +9,7 @@ import type {
   ShortCodesToEmojiData,
 } from 'virtual:mastodon-emoji-compressed';
 
-import { unicodeToUnifiedName } from './unicode_to_unified_name';
+import { unicodeToUnifiedName } from './unicode_utils';
 
 type Emojis = Record<
   NonNullable<keyof ShortCodesToEmojiData>,
@@ -23,7 +23,7 @@ type Emojis = Record<
 
 const [
   shortCodesToEmojiData,
-  skins,
+  _skins,
   categories,
   short_names,
   _emojisWithoutShortCodes,
@@ -47,4 +47,4 @@ Object.keys(shortCodesToEmojiData).forEach((shortCode) => {
   };
 });
 
-export { emojis, skins, categories, short_names };
+export { emojis, categories, short_names };
