@@ -4,9 +4,11 @@ import PickerRaw from 'emoji-mart/dist-es/components/picker/nimble-picker';
 
 import { assetHost } from 'mastodon/utils/config';
 
+import { EMOJI_MODE_NATIVE } from './constants';
 import EmojiData from './emoji_data.json';
+import { useEmojiAppState } from './mode';
 
-const backgroundImageFnDefault = () => `${assetHost}/emoji/sheet_15_1.png`;
+const backgroundImageFnDefault = () => `${assetHost}/emoji/sheet_16_0.png`;
 
 const Emoji = ({
   set = 'twitter',
@@ -16,6 +18,7 @@ const Emoji = ({
   backgroundImageFn = backgroundImageFnDefault,
   ...props
 }: EmojiProps) => {
+  const { mode } = useEmojiAppState();
   return (
     <EmojiRaw
       data={EmojiData}
@@ -23,6 +26,7 @@ const Emoji = ({
       sheetSize={sheetSize}
       sheetColumns={sheetColumns}
       sheetRows={sheetRows}
+      native={mode === EMOJI_MODE_NATIVE}
       backgroundImageFn={backgroundImageFn}
       {...props}
     />
@@ -37,6 +41,7 @@ const Picker = ({
   backgroundImageFn = backgroundImageFnDefault,
   ...props
 }: PickerProps) => {
+  const { mode } = useEmojiAppState();
   return (
     <PickerRaw
       data={EmojiData}
@@ -45,6 +50,7 @@ const Picker = ({
       sheetColumns={sheetColumns}
       sheetRows={sheetRows}
       backgroundImageFn={backgroundImageFn}
+      native={mode === EMOJI_MODE_NATIVE}
       {...props}
     />
   );
