@@ -32,7 +32,11 @@ function getStatusResultFunction(
     };
   }
 
-  if (statusBase.get('isLoading')) {
+  // When a status is loading, a `isLoading` property is set
+  // A status can be loading because it is not known yet (in which case it will only contain `isLoading`)
+  // or because it is being re-fetched; in the latter case, `visibility` will always be set to a non-empty
+  // string.
+  if (statusBase.get('isLoading') && !statusBase.get('visibility')) {
     return {
       status: null,
       loadingState: 'loading',
@@ -74,7 +78,7 @@ function getStatusResultFunction(
       map.set('matched_filters', filtered);
       map.set('matched_media_filters', mediaFiltered);
     }),
-    loadingState: 'complete'
+    loadingState: statusBase.get('isLoading') ? 'loading' : 'complete'
   };
 }
 
