@@ -14,7 +14,7 @@ class Admin::Metrics::Dimension::ServersDimension < Admin::Metrics::Dimension::B
   end
 
   def sql_array
-    [sql_query_string, { earliest_status_id: earliest_status_id, latest_status_id: latest_status_id, limit: @limit }]
+    [sql_query_string, { earliest_status_id:, latest_status_id:, limit: @limit }]
   end
 
   def sql_query_string
@@ -28,12 +28,4 @@ class Admin::Metrics::Dimension::ServersDimension < Admin::Metrics::Dimension::B
       LIMIT :limit
     SQL
   end
-
-  def earliest_status_id
-    Mastodon::Snowflake.id_at(@start_at.beginning_of_day, with_random: false)
-  end
-
-  def latest_status_id
-    Mastodon::Snowflake.id_at(@end_at.end_of_day, with_random: false)
-  end
 end
