@@ -28,7 +28,7 @@ class Admin::Metrics::Measure::InstanceStatusesMeasure < Admin::Metrics::Measure
   end
 
   def sql_array
-    [sql_query_string, { start_at: @start_at, end_at: @end_at, domain: params[:domain], earliest_status_id: earliest_status_id, latest_status_id: latest_status_id }]
+    [sql_query_string, { start_at: @start_at, end_at: @end_at, domain: params[:domain], earliest_status_id:, latest_status_id: }]
   end
 
   def sql_query_string
@@ -50,14 +50,6 @@ class Admin::Metrics::Measure::InstanceStatusesMeasure < Admin::Metrics::Measure
     SQL
   end
 
-  def earliest_status_id
-    Mastodon::Snowflake.id_at(@start_at.beginning_of_day, with_random: false)
-  end
-
-  def latest_status_id
-    Mastodon::Snowflake.id_at(@end_at.end_of_day, with_random: false)
-  end
-
   def params
     @params.permit(:domain, :include_subdomains)
   end
