@@ -10,12 +10,6 @@ module DatabaseViewRecord
         concurrently: true,
         cascade: false
       )
-    rescue ActiveRecord::StatementInvalid
-      Scenic.database.refresh_materialized_view(
-        table_name,
-        concurrently: false,
-        cascade: false
-      )
     end
   end
 
