@@ -5,14 +5,15 @@
 # Table name: status_stats
 #
 #  id                         :bigint(8)        not null, primary key
-#  status_id                  :bigint(8)        not null
-#  replies_count              :bigint(8)        default(0), not null
-#  reblogs_count              :bigint(8)        default(0), not null
 #  favourites_count           :bigint(8)        default(0), not null
-#  created_at                 :datetime         not null
-#  updated_at                 :datetime         not null
+#  quotes_count               :bigint(8)        default(0), not null
+#  reblogs_count              :bigint(8)        default(0), not null
+#  replies_count              :bigint(8)        default(0), not null
 #  untrusted_favourites_count :bigint(8)
 #  untrusted_reblogs_count    :bigint(8)
+#  created_at                 :datetime         not null
+#  updated_at                 :datetime         not null
+#  status_id                  :bigint(8)        not null
 #
 
 class StatusStat < ApplicationRecord
@@ -34,6 +35,10 @@ class StatusStat < ApplicationRecord
     [attributes['favourites_count'], 0].max
   end
 
+  def quotes_count
+    [attributes['quotes_count'], 0].max
+  end
+
   private
 
   def clamp_untrusted_counts
