@@ -1,11 +1,22 @@
 # frozen_string_literal: true
 
 class ActivityPub::QuoteRequestSerializer < ActivityPub::Serializer
+  def self.serializer_for(model, options)
+    case model.class.name
+    when 'Status'
+      ActivityPub::NoteSerializer
+    else
+      super
+    end
+  end
+
   context_extensions :quote_requests
 
-  attributes :id, :type, :actor, :instrument
+  attributes :id, :type, :actor
   attribute :virtual_object, key: :object
 
+  has_one :instrument
+
   def id
     object.activity_uri
   end
@@ -23,6 +34,6 @@ class ActivityPub::QuoteRequestSerializer < ActivityPub::Serializer
   end
 
   def instrument
-    ActivityPub::TagManager.instance.uri_for(object.status)
+    instance_options[:allow_post_inlining] && object.status.local? ? object.status : ActivityPub::TagManager.instance.uri_for(object.status)
   end
 end
