@@ -4,6 +4,7 @@ class REST::PreferencesSerializer < ActiveModel::Serializer
   attribute :posting_default_privacy, key: 'posting:default:visibility'
   attribute :posting_default_sensitive, key: 'posting:default:sensitive'
   attribute :posting_default_language, key: 'posting:default:language'
+  attribute :posting_default_quote_policy, key: 'posting:default:quote_policy'
 
   attribute :reading_default_sensitive_media, key: 'reading:expand:media'
   attribute :reading_default_sensitive_text, key: 'reading:expand:spoilers'
@@ -13,6 +14,10 @@ class REST::PreferencesSerializer < ActiveModel::Serializer
     object.user.setting_default_privacy
   end
 
+  def posting_default_quote_policy
+    object.user.setting_default_quote_policy
+  end
+
   def posting_default_sensitive
     object.user.setting_default_sensitive
   end
