@@ -1,9 +1,7 @@
 # frozen_string_literal: true
 
-class Fasp::AccountSearchWorker
-  include Sidekiq::Worker
-
-  sidekiq_options queue: 'fasp', retry: 0
+class Fasp::AccountSearchWorker < Fasp::BaseWorker
+  sidekiq_options retry: 0
 
   def perform(query)
     return unless Mastodon::Feature.fasp_enabled?
@@ -17,11 +15,13 @@ class Fasp::AccountSearchWorker
     fetch_service = ActivityPub::FetchRemoteActorService.new
 
     account_search_providers.each do |provider|
-      Fasp::Request.new(provider).get("/account_search/v0/search?#{params}").each do |uri|
-        next if Account.where(uri:).any?
+      with_provider(provider) do
+        Fasp::Request.new(provider).get("/account_search/v0/search?#{params}").each do |uri|
+          next if Account.where(uri:).any?
 
-        account = fetch_service.call(uri)
-        async_refresh.increment_result_count(by: 1) if account.present?
+          account = fetch_service.call(uri)
+          async_refresh.increment_result_count(by: 1) if account.present?
+        end
       end
     end
   ensure
