@@ -20,10 +20,6 @@ class RedownloadHeaderWorker
   rescue Mastodon::UnexpectedResponseError => e
     response = e.response
 
-    if response_error_unsalvageable?(response)
-      # Give up
-    else
-      raise e
-    end
+    raise(e) unless response_error_unsalvageable?(response)
   end
 end
