@@ -15,10 +15,6 @@ class RemoteAccountRefreshWorker
   rescue Mastodon::UnexpectedResponseError => e
     response = e.response
 
-    if response_error_unsalvageable?(response)
-      # Give up
-    else
-      raise e
-    end
+    raise(e) unless response_error_unsalvageable?(response)
   end
 end
