@@ -15,11 +15,9 @@ RSpec.describe 'Settings preferences other page' do
 
     check language_field(:es)
     check language_field(:fr)
-    check mark_sensitive_field
 
     expect { save_changes }
       .to change { user.reload.chosen_languages }.to(%w(es fr))
-      .and(change { user.reload.settings.default_sensitive }.to(true))
     expect(page)
       .to have_title(I18n.t('settings.preferences'))
   end
@@ -28,10 +26,6 @@ RSpec.describe 'Settings preferences other page' do
     within('form') { click_on submit_button }
   end
 
-  def mark_sensitive_field
-    form_label('defaults.setting_default_sensitive')
-  end
-
   def language_field(key)
     LanguagesHelper::SUPPORTED_LOCALES[key].last
   end
